# ImmunoViewer
Discover and annotate your (multi-channel) big TIF files with this user-friendly viewer.

### Table of Contents
* [What is ImmunoViewer](#description)  
* [Installation](#installation)  
    * [Install from GitHub](#install-from-github)
    * [Install from pip](#install-from-pip)
    * [Install from Conda](#install-from-conda)
* [Usage](#usage)  
    * [Folder structure](#folder-structure)
    * [Generate tiles](#generate-tiles)
    * [Run the viewer](#run-the-viewer)


### Description
ImmunoViewer is an easy way to view your scanned tif files. 

### Installation
#### Install from github
```bash
git clone https://github.com/davidvi/ImmunoViewer.git
cd ImmunoViewer
python setup.py install
```

#### Install from pip 

#### Install from conda

### Usage
#### Folder structure

#### Generate tiles

#### Run the viewer
